#include "MazeContent/Buildings/Room.h"
#include "Config.h"

Room::Room(float size) : m_rectangle{ {size, size} } {
    m_rectangle.setOrigin(m_rectangle.getSize() / 2.f);
    m_rectangle.setFillColor(config::GAME_COLOR_ROOM);
}

float Room::get_size() const noexcept {
    return m_rectangle.getSize().x;
}

void Room::set_position(const sf::Vector2f& pos) noexcept {
    m_rectangle.setPosition(pos);
}

sf::Vector2f Room::get_position() const noexcept {
    return m_rectangle.getPosition();
}

void Room::set_side(Direction side, std::shared_ptr<IRoomSide> ptr_side) noexcept {
    if (side == INVALID)
        return;
    m_sides.at(side) = std::move(ptr_side);
    m_sides.at(side)->prepare_for_drawing();
}

std::shared_ptr<IRoomSide> Room::get_side(Direction side) {
    return m_sides.at(side);
}

Room::Direction Room::get_direction(IRoomSide* ptr_side) {
    if (m_sides.at(LEFT).get() == ptr_side) return LEFT;
    else if (m_sides.at(RIGHT).get() == ptr_side) return RIGHT;
    else if (m_sides.at(UP).get() == ptr_side) return UP;
    else if (m_sides.at(DOWN).get() == ptr_side) return DOWN;
    return INVALID;
}